<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\AccountAction;
use Bixo\Account\Http\Requests\AccountActionRequest;
use Bixo\Account\Http\Resources\AccountResource;
use Bixo\Account\Models\Account;

/**
 * Admin web controller class.
 */
class AccountActionController extends BaseController
{

    /**
     * Action controller function for account.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AccountActionRequest $request, Account $account, $action)
    {
        try {
            $request = $request->all();
            $account = AccountAction::run($action, $account, $request);

            $data = new AccountResource($account);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::account.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/account/' . $account->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/account/' . $account->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
