<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\AcknowledgementDetailAction;
use Bixo\Account\Http\Requests\AcknowledgementDetailActionRequest;
use Bixo\Account\Http\Resources\AcknowledgementDetailResource;
use Bixo\Account\Models\AcknowledgementDetail;

/**
 * Admin web controller class.
 */
class AcknowledgementDetailActionController extends BaseController
{

    /**
     * Action controller function for acknowledgement_detail.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AcknowledgementDetailActionRequest $request, AcknowledgementDetail $acknowledgement_detail, $action)
    {
        try {
            $request = $request->all();
            $acknowledgement_detail = AcknowledgementDetailAction::run($action, $acknowledgement_detail, $request);

            $data = new AcknowledgementDetailResource($acknowledgement_detail);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::acknowledgement_detail.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/acknowledgement_detail/' . $acknowledgement_detail->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/acknowledgement_detail/' . $acknowledgement_detail->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
