<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\BankAction;
use Bixo\Account\Http\Requests\BankActionRequest;
use Bixo\Account\Http\Resources\BankResource;
use Bixo\Account\Models\Bank;

/**
 * Admin web controller class.
 */
class BankActionController extends BaseController
{

    /**
     * Action controller function for bank.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BankActionRequest $request, Bank $bank, $action)
    {
        try {
            $request = $request->all();
            $bank = BankAction::run($action, $bank, $request);

            $data = new BankResource($bank);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::bank.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/bank/' . $bank->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/bank/' . $bank->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
