<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Account\Http\Requests\BankActionsRequest;
use Bixo\Account\Actions\BankActions;

/**
 * Admin web controller class.
 */
class BankActionsController extends BaseController
{

    /**
     * Action controller function for bank.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BankActionsRequest $request, $action)
    {
        try {
            $bank = BankActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::bank.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/bank/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/bank/' . $action))
                ->redirect();
        }
    }
}
