<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\CustomerAction;
use Bixo\Account\Http\Requests\CustomerActionRequest;
use Bixo\Account\Http\Resources\CustomerResource;
use Bixo\Account\Models\Customer;

/**
 * Admin web controller class.
 */
class CustomerActionController extends BaseController
{

    /**
     * Action controller function for customer.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CustomerActionRequest $request, Customer $customer, $action)
    {
        try {
            $request = $request->all();
            $customer = CustomerAction::run($action, $customer, $request);

            $data = new CustomerResource($customer);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::customer.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/customer/' . $customer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/customer/' . $customer->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
