<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Account\Http\Requests\CustomerActionsRequest;
use Bixo\Account\Actions\CustomerActions;

/**
 * Admin web controller class.
 */
class CustomerActionsController extends BaseController
{

    /**
     * Action controller function for customer.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CustomerActionsRequest $request, $action)
    {
        try {
            $customer = CustomerActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::customer.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/customer/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/customer/' . $action))
                ->redirect();
        }
    }
}
