<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Account\Http\Resources\AccountResource;
use Bixo\Account\Http\Resources\AccountsCollection;
use Bixo\Account\Scopes\CustomerPublicScope;
use Bixo\Account\Models\Customer;

class CustomerPublicController extends BaseController
{

    /**
     * Show customer's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Customer::pushScope(new RequestScope())
            ->pushScope(new CustomerPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $customers = new CustomersCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('account::customer.names'))
            ->view('account::public.customer.index')
            ->data(compact('customers', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show customer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Customer::findBySlug($slug);
        $data = new CustomerResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('account::customer.name'))
            ->view('account::public.customer.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
