<?php

namespace Bixo\Account\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Account\Forms\DrcrnoteDetail as DrcrnoteDetailForm;
use Bixo\Account\Http\Requests\DrcrnoteDetailResourceRequest;
use Bixo\Account\Http\Resources\DrcrnoteDetailResource;
use Bixo\Account\Http\Resources\DrcrnoteDetailsCollection;
use Bixo\Account\Models\DrcrnoteDetail;
use Bixo\Account\Actions\DrcrnoteDetailAction;
use Bixo\Account\Actions\DrcrnoteDetailActions;


/**
 * Resource controller class for drcrnote_detail.
 */
class DrcrnoteDetailResourceController extends BaseController
{

    /**
     * Initialize drcrnote_detail resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = DrcrnoteDetailForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.account.modules'), 'account', guard_url('account'));
            return $next($request);
        });
    }

    /**
     * Display a list of drcrnote_detail.
     *
     * @return Response
     */
    public function index(DrcrnoteDetailResourceRequest $request)
    {
        $request = $request->all();
        $page = DrcrnoteDetailActions::run('paginate', $request);

        $data = new DrcrnoteDetailsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('account::drcrnote_detail.names'))
            ->view('account::drcrnote_detail.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display drcrnote_detail.
     *
     * @param Request $request
     * @param Model   $drcrnote_detail
     *
     * @return Response
     */
    public function show(DrcrnoteDetailResourceRequest $request, DrcrnoteDetail $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new DrcrnoteDetailResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('account::drcrnote_detail.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('account::drcrnote_detail.show')
            ->output();
    }

    /**
     * Show the form for creating a new drcrnote_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DrcrnoteDetailResourceRequest $request, DrcrnoteDetail $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new DrcrnoteDetailResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('account::drcrnote_detail.name'))
            ->view('account::drcrnote_detail.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new drcrnote_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DrcrnoteDetailResourceRequest $request, DrcrnoteDetail $model)
    {
        try {
            $request = $request->all();
            $model = DrcrnoteDetailAction::run('store', $model, $request);
            $data = new DrcrnoteDetailResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('account::drcrnote_detail.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/drcrnote_detail/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/account/drcrnote_detail'))
                ->redirect();
        }

    }

    /**
     * Show drcrnote_detail for editing.
     *
     * @param Request $request
     * @param Model   $drcrnote_detail
     *
     * @return Response
     */
    public function edit(DrcrnoteDetailResourceRequest $request, DrcrnoteDetail $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new DrcrnoteDetailResource($model);
        // return view('account::drcrnote_detail.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('account::drcrnote_detail.name'))
            ->view('account::drcrnote_detail.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the drcrnote_detail.
     *
     * @param Request $request
     * @param Model   $drcrnote_detail
     *
     * @return Response
     */
    public function update(DrcrnoteDetailResourceRequest $request, DrcrnoteDetail $model)
    {
        try {
            $request = $request->all();
            $model = DrcrnoteDetailAction::run('update', $model, $request);
            $data = new DrcrnoteDetailResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::drcrnote_detail.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('account/drcrnote_detail/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/drcrnote_detail/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the drcrnote_detail.
     *
     * @param Model   $drcrnote_detail
     *
     * @return Response
     */
    public function destroy(DrcrnoteDetailResourceRequest $request, DrcrnoteDetail $model)
    {
        try {

            $request = $request->all();
            $model = DrcrnoteDetailAction::run('destroy', $model, $request);
            $data = new DrcrnoteDetailResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('account::drcrnote_detail.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('account/drcrnote_detail/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/drcrnote_detail/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
