<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Account\Actions\InvoiceExim;
use Bixo\Account\Http\Requests\InvoiceEximRequest;

/**
 * Admin web controller class.
 */
class InvoiceEximController extends BaseController
{
    /**
     * Action controller function for invoice.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InvoiceEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = InvoiceExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account:invoice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice/' . $exim))
                ->redirect();
        }
    }
}
