<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\JournalAction;
use Bixo\Account\Http\Requests\JournalActionRequest;
use Bixo\Account\Http\Resources\JournalResource;
use Bixo\Account\Models\Journal;

/**
 * Admin web controller class.
 */
class JournalActionController extends BaseController
{

    /**
     * Action controller function for journal.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(JournalActionRequest $request, Journal $journal, $action)
    {
        try {
            $request = $request->all();
            $journal = JournalAction::run($action, $journal, $request);

            $data = new JournalResource($journal);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::journal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/journal/' . $journal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/journal/' . $journal->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
