<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\PayrecAction;
use Bixo\Account\Http\Requests\PayrecActionRequest;
use Bixo\Account\Http\Resources\PayrecResource;
use Bixo\Account\Models\Payrec;

/**
 * Admin web controller class.
 */
class PayrecActionController extends BaseController
{

    /**
     * Action controller function for payrec.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PayrecActionRequest $request, Payrec $payrec, $action)
    {
        try {
            $request = $request->all();
            $payrec = PayrecAction::run($action, $payrec, $request);

            $data = new PayrecResource($payrec);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::payrec.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/payrec/' . $payrec->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/payrec/' . $payrec->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
