<?php

namespace Bixo\Account\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Account\Forms\PayrecDetail as PayrecDetailForm;
use Bixo\Account\Http\Requests\PayrecDetailResourceRequest;
use Bixo\Account\Http\Resources\PayrecDetailResource;
use Bixo\Account\Http\Resources\PayrecDetailsCollection;
use Bixo\Account\Models\PayrecDetail;
use Bixo\Account\Actions\PayrecDetailAction;
use Bixo\Account\Actions\PayrecDetailActions;


/**
 * Resource controller class for payrec_detail.
 */
class PayrecDetailResourceController extends BaseController
{

    /**
     * Initialize payrec_detail resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = PayrecDetailForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.account.modules'), 'account', guard_url('account'));
            return $next($request);
        });
    }

    /**
     * Display a list of payrec_detail.
     *
     * @return Response
     */
    public function index(PayrecDetailResourceRequest $request)
    {
        $request = $request->all();
        $page = PayrecDetailActions::run('paginate', $request);

        $data = new PayrecDetailsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('account::payrec_detail.names'))
            ->view('account::payrec_detail.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display payrec_detail.
     *
     * @param Request $request
     * @param Model   $payrec_detail
     *
     * @return Response
     */
    public function show(PayrecDetailResourceRequest $request, PayrecDetail $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PayrecDetailResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('account::payrec_detail.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('account::payrec_detail.show')
            ->output();
    }

    /**
     * Show the form for creating a new payrec_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PayrecDetailResourceRequest $request, PayrecDetail $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PayrecDetailResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('account::payrec_detail.name'))
            ->view('account::payrec_detail.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new payrec_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PayrecDetailResourceRequest $request, PayrecDetail $model)
    {
        try {
            $request = $request->all();
            $model = PayrecDetailAction::run('store', $model, $request);
            $data = new PayrecDetailResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('account::payrec_detail.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/payrec_detail/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/account/payrec_detail'))
                ->redirect();
        }

    }

    /**
     * Show payrec_detail for editing.
     *
     * @param Request $request
     * @param Model   $payrec_detail
     *
     * @return Response
     */
    public function edit(PayrecDetailResourceRequest $request, PayrecDetail $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PayrecDetailResource($model);
        // return view('account::payrec_detail.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('account::payrec_detail.name'))
            ->view('account::payrec_detail.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the payrec_detail.
     *
     * @param Request $request
     * @param Model   $payrec_detail
     *
     * @return Response
     */
    public function update(PayrecDetailResourceRequest $request, PayrecDetail $model)
    {
        try {
            $request = $request->all();
            $model = PayrecDetailAction::run('update', $model, $request);
            $data = new PayrecDetailResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::payrec_detail.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('account/payrec_detail/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/payrec_detail/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the payrec_detail.
     *
     * @param Model   $payrec_detail
     *
     * @return Response
     */
    public function destroy(PayrecDetailResourceRequest $request, PayrecDetail $model)
    {
        try {

            $request = $request->all();
            $model = PayrecDetailAction::run('destroy', $model, $request);
            $data = new PayrecDetailResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('account::payrec_detail.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('account/payrec_detail/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/payrec_detail/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
