<?php

namespace Bixo\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Account\Actions\TransactionsDetailAction;
use Bixo\Account\Http\Requests\TransactionsDetailActionRequest;
use Bixo\Account\Http\Resources\TransactionsDetailResource;
use Bixo\Account\Models\TransactionsDetail;

/**
 * Admin web controller class.
 */
class TransactionsDetailActionController extends BaseController
{

    /**
     * Action controller function for transactions_detail.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TransactionsDetailActionRequest $request, TransactionsDetail $transactions_detail, $action)
    {
        try {
            $request = $request->all();
            $transactions_detail = TransactionsDetailAction::run($action, $transactions_detail, $request);

            $data = new TransactionsDetailResource($transactions_detail);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::transactions_detail.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/transactions_detail/' . $transactions_detail->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/transactions_detail/' . $transactions_detail->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
