<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\AcknowledgementAction as AcknowledgementActionEvent;
use Bixo\Account\Notifications\AcknowledgementAction as AcknowledgementActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AcknowledgementAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AcknowledgementActionEvent.
     *
     * @param   AcknowledgementActionEvent  $event
     * @return mixed
     */
    public function handle(AcknowledgementActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $acknowledgement.
     *
     * @param   AcknowledgementActionEvent  $event
     * @return void
     */
    public function create(AcknowledgementActionEvent $event)
    {
        $client = $event->acknowledgement->client;
        Notification::send($client, new AcknowledgementActionNotification($event));
    }

    /**
     * Handle the AcknowledgementActionEvent as a listener.
     *
     * @param   AcknowledgementActionEvent  $event
     * @return mixed
     */
    public function asListener(AcknowledgementActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AcknowledgementActionEvent  $event
     * @return bool
     */
    private function isAllowed(AcknowledgementActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
