<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\AcknowledgementDetailAction as AcknowledgementDetailActionEvent;
use Bixo\Account\Notifications\AcknowledgementDetailAction as AcknowledgementDetailActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AcknowledgementDetailAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AcknowledgementDetailActionEvent.
     *
     * @param   AcknowledgementDetailActionEvent  $event
     * @return mixed
     */
    public function handle(AcknowledgementDetailActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $acknowledgement_detail.
     *
     * @param   AcknowledgementDetailActionEvent  $event
     * @return void
     */
    public function create(AcknowledgementDetailActionEvent $event)
    {
        $client = $event->acknowledgement_detail->client;
        Notification::send($client, new AcknowledgementDetailActionNotification($event));
    }

    /**
     * Handle the AcknowledgementDetailActionEvent as a listener.
     *
     * @param   AcknowledgementDetailActionEvent  $event
     * @return mixed
     */
    public function asListener(AcknowledgementDetailActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AcknowledgementDetailActionEvent  $event
     * @return bool
     */
    private function isAllowed(AcknowledgementDetailActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
