<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\AcknowledgementDetailWorkflow as AcknowledgementDetailWorkflowEvent;
use Bixo\Account\Notifications\AcknowledgementDetailWorkflow as AcknowledgementDetailWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AcknowledgementDetailWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AcknowledgementDetailWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $acknowledgement_detail is submitted.
     *
     * @param AcknowledgementDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AcknowledgementDetailWorkflowEvent $event)
    {
        $client = $event->acknowledgement_detail->client;
        Notification::send($client, new AcknowledgementDetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $acknowledgement_detail is published.
     *
     * @param AcknowledgementDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AcknowledgementDetailWorkflowEvent $event)
    {
        $client = $event->acknowledgement_detail->client;
        Notification::send($client, new AcknowledgementDetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $acknowledgement_detail is approved.
     *
     * @param AcknowledgementDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AcknowledgementDetailWorkflowEvent $event)
    {
        $client = $event->acknowledgement_detail->client;
        Notification::send($client, new AcknowledgementDetailWorkflowNotification($event));
    }

    /**
     * Handles the $acknowledgement_detail workflow event as a listener.
     *
     * @param AcknowledgementDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AcknowledgementDetailWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
