<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\DrcrnoteDetailAction as DrcrnoteDetailActionEvent;
use Bixo\Account\Notifications\DrcrnoteDetailAction as DrcrnoteDetailActionNotification;
use Litepie\Actions\Concerns\AsAction;

class DrcrnoteDetailAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the DrcrnoteDetailActionEvent.
     *
     * @param   DrcrnoteDetailActionEvent  $event
     * @return mixed
     */
    public function handle(DrcrnoteDetailActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $drcrnote_detail.
     *
     * @param   DrcrnoteDetailActionEvent  $event
     * @return void
     */
    public function create(DrcrnoteDetailActionEvent $event)
    {
        $client = $event->drcrnote_detail->client;
        Notification::send($client, new DrcrnoteDetailActionNotification($event));
    }

    /**
     * Handle the DrcrnoteDetailActionEvent as a listener.
     *
     * @param   DrcrnoteDetailActionEvent  $event
     * @return mixed
     */
    public function asListener(DrcrnoteDetailActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   DrcrnoteDetailActionEvent  $event
     * @return bool
     */
    private function isAllowed(DrcrnoteDetailActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
