<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\DrcrnoteDetailWorkflow as DrcrnoteDetailWorkflowEvent;
use Bixo\Account\Notifications\DrcrnoteDetailWorkflow as DrcrnoteDetailWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class DrcrnoteDetailWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(DrcrnoteDetailWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $drcrnote_detail is submitted.
     *
     * @param DrcrnoteDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(DrcrnoteDetailWorkflowEvent $event)
    {
        $client = $event->drcrnote_detail->client;
        Notification::send($client, new DrcrnoteDetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $drcrnote_detail is published.
     *
     * @param DrcrnoteDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(DrcrnoteDetailWorkflowEvent $event)
    {
        $client = $event->drcrnote_detail->client;
        Notification::send($client, new DrcrnoteDetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $drcrnote_detail is approved.
     *
     * @param DrcrnoteDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(DrcrnoteDetailWorkflowEvent $event)
    {
        $client = $event->drcrnote_detail->client;
        Notification::send($client, new DrcrnoteDetailWorkflowNotification($event));
    }

    /**
     * Handles the $drcrnote_detail workflow event as a listener.
     *
     * @param DrcrnoteDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(DrcrnoteDetailWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
