<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\DrcrnoteWorkflow as DrcrnoteWorkflowEvent;
use Bixo\Account\Notifications\DrcrnoteWorkflow as DrcrnoteWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class DrcrnoteWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(DrcrnoteWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $drcrnote is submitted.
     *
     * @param DrcrnoteWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(DrcrnoteWorkflowEvent $event)
    {
        $client = $event->drcrnote->client;
        Notification::send($client, new DrcrnoteWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $drcrnote is published.
     *
     * @param DrcrnoteWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(DrcrnoteWorkflowEvent $event)
    {
        $client = $event->drcrnote->client;
        Notification::send($client, new DrcrnoteWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $drcrnote is approved.
     *
     * @param DrcrnoteWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(DrcrnoteWorkflowEvent $event)
    {
        $client = $event->drcrnote->client;
        Notification::send($client, new DrcrnoteWorkflowNotification($event));
    }

    /**
     * Handles the $drcrnote workflow event as a listener.
     *
     * @param DrcrnoteWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(DrcrnoteWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
