<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\InvoiceDetailAction as InvoiceDetailActionEvent;
use Bixo\Account\Notifications\InvoiceDetailAction as InvoiceDetailActionNotification;
use Litepie\Actions\Concerns\AsAction;

class InvoiceDetailAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the InvoiceDetailActionEvent.
     *
     * @param   InvoiceDetailActionEvent  $event
     * @return mixed
     */
    public function handle(InvoiceDetailActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $invoice_detail.
     *
     * @param   InvoiceDetailActionEvent  $event
     * @return void
     */
    public function create(InvoiceDetailActionEvent $event)
    {
        $client = $event->invoice_detail->client;
        Notification::send($client, new InvoiceDetailActionNotification($event));
    }

    /**
     * Handle the InvoiceDetailActionEvent as a listener.
     *
     * @param   InvoiceDetailActionEvent  $event
     * @return mixed
     */
    public function asListener(InvoiceDetailActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   InvoiceDetailActionEvent  $event
     * @return bool
     */
    private function isAllowed(InvoiceDetailActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
