<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\JournalDetailAction as JournalDetailActionEvent;
use Bixo\Account\Notifications\JournalDetailAction as JournalDetailActionNotification;
use Litepie\Actions\Concerns\AsAction;

class JournalDetailAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the JournalDetailActionEvent.
     *
     * @param   JournalDetailActionEvent  $event
     * @return mixed
     */
    public function handle(JournalDetailActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $journal_detail.
     *
     * @param   JournalDetailActionEvent  $event
     * @return void
     */
    public function create(JournalDetailActionEvent $event)
    {
        $client = $event->journal_detail->client;
        Notification::send($client, new JournalDetailActionNotification($event));
    }

    /**
     * Handle the JournalDetailActionEvent as a listener.
     *
     * @param   JournalDetailActionEvent  $event
     * @return mixed
     */
    public function asListener(JournalDetailActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   JournalDetailActionEvent  $event
     * @return bool
     */
    private function isAllowed(JournalDetailActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
