<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\PayrecDetailAction as PayrecDetailActionEvent;
use Bixo\Account\Notifications\PayrecDetailAction as PayrecDetailActionNotification;
use Litepie\Actions\Concerns\AsAction;

class PayrecDetailAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the PayrecDetailActionEvent.
     *
     * @param   PayrecDetailActionEvent  $event
     * @return mixed
     */
    public function handle(PayrecDetailActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $payrec_detail.
     *
     * @param   PayrecDetailActionEvent  $event
     * @return void
     */
    public function create(PayrecDetailActionEvent $event)
    {
        $client = $event->payrec_detail->client;
        Notification::send($client, new PayrecDetailActionNotification($event));
    }

    /**
     * Handle the PayrecDetailActionEvent as a listener.
     *
     * @param   PayrecDetailActionEvent  $event
     * @return mixed
     */
    public function asListener(PayrecDetailActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   PayrecDetailActionEvent  $event
     * @return bool
     */
    private function isAllowed(PayrecDetailActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
