<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\PayrecDetailWorkflow as PayrecDetailWorkflowEvent;
use Bixo\Account\Notifications\PayrecDetailWorkflow as PayrecDetailWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PayrecDetailWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PayrecDetailWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $payrec_detail is submitted.
     *
     * @param PayrecDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PayrecDetailWorkflowEvent $event)
    {
        $client = $event->payrec_detail->client;
        Notification::send($client, new PayrecDetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $payrec_detail is published.
     *
     * @param PayrecDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PayrecDetailWorkflowEvent $event)
    {
        $client = $event->payrec_detail->client;
        Notification::send($client, new PayrecDetailWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $payrec_detail is approved.
     *
     * @param PayrecDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PayrecDetailWorkflowEvent $event)
    {
        $client = $event->payrec_detail->client;
        Notification::send($client, new PayrecDetailWorkflowNotification($event));
    }

    /**
     * Handles the $payrec_detail workflow event as a listener.
     *
     * @param PayrecDetailWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PayrecDetailWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
