<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\PayrecReceiptsWorkflow as PayrecReceiptsWorkflowEvent;
use Bixo\Account\Notifications\PayrecReceiptsWorkflow as PayrecReceiptsWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PayrecReceiptsWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PayrecReceiptsWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $payrec_receipts is submitted.
     *
     * @param PayrecReceiptsWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PayrecReceiptsWorkflowEvent $event)
    {
        $client = $event->payrec_receipts->client;
        Notification::send($client, new PayrecReceiptsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $payrec_receipts is published.
     *
     * @param PayrecReceiptsWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PayrecReceiptsWorkflowEvent $event)
    {
        $client = $event->payrec_receipts->client;
        Notification::send($client, new PayrecReceiptsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $payrec_receipts is approved.
     *
     * @param PayrecReceiptsWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PayrecReceiptsWorkflowEvent $event)
    {
        $client = $event->payrec_receipts->client;
        Notification::send($client, new PayrecReceiptsWorkflowNotification($event));
    }

    /**
     * Handles the $payrec_receipts workflow event as a listener.
     *
     * @param PayrecReceiptsWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PayrecReceiptsWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
