<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\PayrecWorkflow as PayrecWorkflowEvent;
use Bixo\Account\Notifications\PayrecWorkflow as PayrecWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PayrecWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PayrecWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $payrec is submitted.
     *
     * @param PayrecWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PayrecWorkflowEvent $event)
    {
        $client = $event->payrec->client;
        Notification::send($client, new PayrecWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $payrec is published.
     *
     * @param PayrecWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PayrecWorkflowEvent $event)
    {
        $client = $event->payrec->client;
        Notification::send($client, new PayrecWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $payrec is approved.
     *
     * @param PayrecWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PayrecWorkflowEvent $event)
    {
        $client = $event->payrec->client;
        Notification::send($client, new PayrecWorkflowNotification($event));
    }

    /**
     * Handles the $payrec workflow event as a listener.
     *
     * @param PayrecWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PayrecWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
