<?php

namespace Bixo\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Account\Events\TransactionsDetailAction as TransactionsDetailActionEvent;
use Bixo\Account\Notifications\TransactionsDetailAction as TransactionsDetailActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TransactionsDetailAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TransactionsDetailActionEvent.
     *
     * @param   TransactionsDetailActionEvent  $event
     * @return mixed
     */
    public function handle(TransactionsDetailActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $transactions_detail.
     *
     * @param   TransactionsDetailActionEvent  $event
     * @return void
     */
    public function create(TransactionsDetailActionEvent $event)
    {
        $client = $event->transactions_detail->client;
        Notification::send($client, new TransactionsDetailActionNotification($event));
    }

    /**
     * Handle the TransactionsDetailActionEvent as a listener.
     *
     * @param   TransactionsDetailActionEvent  $event
     * @return mixed
     */
    public function asListener(TransactionsDetailActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TransactionsDetailActionEvent  $event
     * @return bool
     */
    private function isAllowed(TransactionsDetailActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
