<?php
namespace Bixo\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Account\Events\AccountAction as AccountActionEvent;
use Bixo\Account\Models\Account;

class AccountAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $account;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AccountActionEvent $account
     */
    public function __construct(AccountActionEvent $account)
    {
        $this->action = $event->action;
        $this->account = $account;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Account Approved - ' . config('app.name'))
            ->view('account::account.email.action', ['data' => $this->account]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
