<?php
namespace Bixo\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Account\Events\AcknowledgementDetailAction as AcknowledgementDetailActionEvent;
use Bixo\Account\Models\AcknowledgementDetail;

class AcknowledgementDetailAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $acknowledgement_detail;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AcknowledgementDetailActionEvent $acknowledgement_detail
     */
    public function __construct(AcknowledgementDetailActionEvent $acknowledgement_detail)
    {
        $this->action = $event->action;
        $this->acknowledgement_detail = $acknowledgement_detail;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('AcknowledgementDetail Approved - ' . config('app.name'))
            ->view('account::acknowledgement_detail.email.action', ['data' => $this->acknowledgement_detail]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
