<?php
namespace Bixo\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Account\Events\CustomerAction as CustomerActionEvent;
use Bixo\Account\Models\Customer;

class CustomerAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $customer;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CustomerActionEvent $customer
     */
    public function __construct(CustomerActionEvent $customer)
    {
        $this->action = $event->action;
        $this->customer = $customer;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Customer Approved - ' . config('app.name'))
            ->view('account::customer.email.action', ['data' => $this->customer]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
