<?php
namespace Bixo\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Account\Events\JournalAction as JournalActionEvent;
use Bixo\Account\Models\Journal;

class JournalAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $journal;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param JournalActionEvent $journal
     */
    public function __construct(JournalActionEvent $journal)
    {
        $this->action = $event->action;
        $this->journal = $journal;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Journal Approved - ' . config('app.name'))
            ->view('account::journal.email.action', ['data' => $this->journal]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
