<?php
namespace Bixo\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Account\Events\TransactionsDetailAction as TransactionsDetailActionEvent;
use Bixo\Account\Models\TransactionsDetail;

class TransactionsDetailAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $transactions_detail;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param TransactionsDetailActionEvent $transactions_detail
     */
    public function __construct(TransactionsDetailActionEvent $transactions_detail)
    {
        $this->action = $event->action;
        $this->transactions_detail = $transactions_detail;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('TransactionsDetail Approved - ' . config('app.name'))
            ->view('account::transactions_detail.email.action', ['data' => $this->transactions_detail]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
