<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\Acknowledgement;

class AcknowledgementPolicy
{


    /**
     * Determine if the given user can view the acknowledgement.
     *
     * @param Authenticatable $user
     * @param Acknowledgement $acknowledgement
     *
     * @return bool
     */
    public function view(Authenticatable $user, Acknowledgement $acknowledgement)
    {
        if ($authUser->canDo('account.acknowledgement.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $acknowledgement->is_owner;
    }

    /**
     * Determine if the given user can create a acknowledgement.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.acknowledgement.create');
    }

    /**
     * Determine if the given user can update the given acknowledgement.
     *
     * @param Authenticatable $user
     * @param Acknowledgement $acknowledgement
     *
     * @return bool
     */
    public function update(Authenticatable $user, Acknowledgement $acknowledgement)
    {
        if ($user->canDo('account.acknowledgement.edit') && $user->isAdmin()) {
            return true;
        }

        return $acknowledgement->is_owner;
    }

    /**
     * Determine if the given user can delete the given acknowledgement.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Acknowledgement $acknowledgement)
    {
        return $acknowledgement->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
