<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\Allocation;

class AllocationPolicy
{


    /**
     * Determine if the given user can view the allocation.
     *
     * @param Authenticatable $user
     * @param Allocation $allocation
     *
     * @return bool
     */
    public function view(Authenticatable $user, Allocation $allocation)
    {
        if ($authUser->canDo('account.allocation.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $allocation->is_owner;
    }

    /**
     * Determine if the given user can create a allocation.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.allocation.create');
    }

    /**
     * Determine if the given user can update the given allocation.
     *
     * @param Authenticatable $user
     * @param Allocation $allocation
     *
     * @return bool
     */
    public function update(Authenticatable $user, Allocation $allocation)
    {
        if ($user->canDo('account.allocation.edit') && $user->isAdmin()) {
            return true;
        }

        return $allocation->is_owner;
    }

    /**
     * Determine if the given user can delete the given allocation.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Allocation $allocation)
    {
        return $allocation->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
