<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\Bank;

class BankPolicy
{

    use BankAction;
    use BankWorkflow;

    /**
     * Determine if the given user can view the bank.
     *
     * @param Authenticatable $user
     * @param Bank $bank
     *
     * @return bool
     */
    public function view(Authenticatable $user, Bank $bank)
    {
        if ($authUser->canDo('account.bank.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $bank->is_owner;
    }

    /**
     * Determine if the given user can create a bank.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.bank.create');
    }

    /**
     * Determine if the given user can update the given bank.
     *
     * @param Authenticatable $user
     * @param Bank $bank
     *
     * @return bool
     */
    public function update(Authenticatable $user, Bank $bank)
    {
        if ($user->canDo('account.bank.edit') && $user->isAdmin()) {
            return true;
        }

        return $bank->is_owner;
    }

    /**
     * Determine if the given user can delete the given bank.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Bank $bank)
    {
        return $bank->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
