<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\DrcrnoteDetail;

class DrcrnoteDetailPolicy
{

    use DrcrnoteDetailAction;
    use DrcrnoteDetailWorkflow;

    /**
     * Determine if the given user can view the drcrnote_detail.
     *
     * @param Authenticatable $user
     * @param DrcrnoteDetail $drcrnote_detail
     *
     * @return bool
     */
    public function view(Authenticatable $user, DrcrnoteDetail $drcrnote_detail)
    {
        if ($authUser->canDo('account.drcrnote_detail.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $drcrnote_detail->is_owner;
    }

    /**
     * Determine if the given user can create a drcrnote_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.drcrnote_detail.create');
    }

    /**
     * Determine if the given user can update the given drcrnote_detail.
     *
     * @param Authenticatable $user
     * @param DrcrnoteDetail $drcrnote_detail
     *
     * @return bool
     */
    public function update(Authenticatable $user, DrcrnoteDetail $drcrnote_detail)
    {
        if ($user->canDo('account.drcrnote_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $drcrnote_detail->is_owner;
    }

    /**
     * Determine if the given user can delete the given drcrnote_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, DrcrnoteDetail $drcrnote_detail)
    {
        return $drcrnote_detail->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
