<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\Drcrnote;

class DrcrnotePolicy
{

    use DrcrnoteAction;
    use DrcrnoteWorkflow;

    /**
     * Determine if the given user can view the drcrnote.
     *
     * @param Authenticatable $user
     * @param Drcrnote $drcrnote
     *
     * @return bool
     */
    public function view(Authenticatable $user, Drcrnote $drcrnote)
    {
        if ($authUser->canDo('account.drcrnote.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $drcrnote->is_owner;
    }

    /**
     * Determine if the given user can create a drcrnote.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.drcrnote.create');
    }

    /**
     * Determine if the given user can update the given drcrnote.
     *
     * @param Authenticatable $user
     * @param Drcrnote $drcrnote
     *
     * @return bool
     */
    public function update(Authenticatable $user, Drcrnote $drcrnote)
    {
        if ($user->canDo('account.drcrnote.edit') && $user->isAdmin()) {
            return true;
        }

        return $drcrnote->is_owner;
    }

    /**
     * Determine if the given user can delete the given drcrnote.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Drcrnote $drcrnote)
    {
        return $drcrnote->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
