<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\InvoiceDetail;

class InvoiceDetailPolicy
{


    /**
     * Determine if the given user can view the invoice_detail.
     *
     * @param Authenticatable $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function view(Authenticatable $user, InvoiceDetail $invoice_detail)
    {
        if ($authUser->canDo('account.invoice_detail.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $invoice_detail->is_owner;
    }

    /**
     * Determine if the given user can create a invoice_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.invoice_detail.create');
    }

    /**
     * Determine if the given user can update the given invoice_detail.
     *
     * @param Authenticatable $user
     * @param InvoiceDetail $invoice_detail
     *
     * @return bool
     */
    public function update(Authenticatable $user, InvoiceDetail $invoice_detail)
    {
        if ($user->canDo('account.invoice_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $invoice_detail->is_owner;
    }

    /**
     * Determine if the given user can delete the given invoice_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, InvoiceDetail $invoice_detail)
    {
        return $invoice_detail->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
