<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\JournalDetail;

class JournalDetailPolicy
{


    /**
     * Determine if the given user can view the journal_detail.
     *
     * @param Authenticatable $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function view(Authenticatable $user, JournalDetail $journal_detail)
    {
        if ($authUser->canDo('account.journal_detail.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $journal_detail->is_owner;
    }

    /**
     * Determine if the given user can create a journal_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.journal_detail.create');
    }

    /**
     * Determine if the given user can update the given journal_detail.
     *
     * @param Authenticatable $user
     * @param JournalDetail $journal_detail
     *
     * @return bool
     */
    public function update(Authenticatable $user, JournalDetail $journal_detail)
    {
        if ($user->canDo('account.journal_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $journal_detail->is_owner;
    }

    /**
     * Determine if the given user can delete the given journal_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, JournalDetail $journal_detail)
    {
        return $journal_detail->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
