<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\Payrec;

class PayrecPolicy
{

    use PayrecAction;
    use PayrecWorkflow;

    /**
     * Determine if the given user can view the payrec.
     *
     * @param Authenticatable $user
     * @param Payrec $payrec
     *
     * @return bool
     */
    public function view(Authenticatable $user, Payrec $payrec)
    {
        if ($authUser->canDo('account.payrec.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $payrec->is_owner;
    }

    /**
     * Determine if the given user can create a payrec.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.payrec.create');
    }

    /**
     * Determine if the given user can update the given payrec.
     *
     * @param Authenticatable $user
     * @param Payrec $payrec
     *
     * @return bool
     */
    public function update(Authenticatable $user, Payrec $payrec)
    {
        if ($user->canDo('account.payrec.edit') && $user->isAdmin()) {
            return true;
        }

        return $payrec->is_owner;
    }

    /**
     * Determine if the given user can delete the given payrec.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Payrec $payrec)
    {
        return $payrec->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
