<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\PayrecReceipts;

class PayrecReceiptsPolicy
{


    /**
     * Determine if the given user can view the payrec_receipts.
     *
     * @param Authenticatable $user
     * @param PayrecReceipts $payrec_receipts
     *
     * @return bool
     */
    public function view(Authenticatable $user, PayrecReceipts $payrec_receipts)
    {
        if ($authUser->canDo('account.payrec_receipts.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $payrec_receipts->is_owner;
    }

    /**
     * Determine if the given user can create a payrec_receipts.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.payrec_receipts.create');
    }

    /**
     * Determine if the given user can update the given payrec_receipts.
     *
     * @param Authenticatable $user
     * @param PayrecReceipts $payrec_receipts
     *
     * @return bool
     */
    public function update(Authenticatable $user, PayrecReceipts $payrec_receipts)
    {
        if ($user->canDo('account.payrec_receipts.edit') && $user->isAdmin()) {
            return true;
        }

        return $payrec_receipts->is_owner;
    }

    /**
     * Determine if the given user can delete the given payrec_receipts.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, PayrecReceipts $payrec_receipts)
    {
        return $payrec_receipts->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
