<?php

namespace Bixo\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Account\Models\TransactionsDetail;

class TransactionsDetailPolicy
{

    use TransactionsDetailAction;
    use TransactionsDetailWorkflow;

    /**
     * Determine if the given user can view the transactions_detail.
     *
     * @param Authenticatable $user
     * @param TransactionsDetail $transactions_detail
     *
     * @return bool
     */
    public function view(Authenticatable $user, TransactionsDetail $transactions_detail)
    {
        if ($authUser->canDo('account.transactions_detail.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $transactions_detail->is_owner;
    }

    /**
     * Determine if the given user can create a transactions_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.transactions_detail.create');
    }

    /**
     * Determine if the given user can update the given transactions_detail.
     *
     * @param Authenticatable $user
     * @param TransactionsDetail $transactions_detail
     *
     * @return bool
     */
    public function update(Authenticatable $user, TransactionsDetail $transactions_detail)
    {
        if ($user->canDo('account.transactions_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $transactions_detail->is_owner;
    }

    /**
     * Determine if the given user can delete the given transactions_detail.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, TransactionsDetail $transactions_detail)
    {
        return $transactions_detail->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
